==> egov-common-1.1.10-sources.jar: com/gtis/plat/vo/PfTaskVo.java <==
package com.gtis.plat.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.HashMap;

public class PfTaskVo implements Serializable {

    private String taskId;

    private String activityId;

    private boolean accepted;

    private PfUserVo userVo;

    private String remark;

    private boolean agree;

    private String performerId;

    private boolean backState;

    private String taskBefore = "";
    private Date beginTime;
    private Date finishTime;
    private boolean repeat;
    private Date overTime;    //任务截止时间

    /**
     * 扩展参数
     * 方便以后平台扩展，不用每次都要修改实体类
     */
    HashMap extensionMap;

    public Date getOverTime() {
        return overTime;
    }

    public void setOverTime(Date overTime) {
        this.overTime = overTime;
    }

    public boolean isRepeat() {
        return repeat;
    }

    public void setRepeat(boolean repeat) {
        this.repeat = repeat;
    }

    public Date getFinishTime() {
        return finishTime;
    }

    public void setFinishTime(Date finishTime) {
        this.finishTime = finishTime;
    }

    public Date getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(Date beginTime) {
        this.beginTime = beginTime;
    }

    public boolean isBackState() {
        return backState;
    }

    public void setBackState(boolean backState) {
        this.backState = backState;
    }

    public String getTaskBefore() {
        return taskBefore;
    }

    public void setTaskBefore(String taskBefore) {
        this.taskBefore = taskBefore;
    }

    public String getPerformerId() {
        return performerId;
    }

    public void setPerformerId(String performerId) {
        this.performerId = performerId;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public boolean isAgree() {
        return agree;
    }

    public void setAgree(boolean agree) {
        this.agree = agree;
    }

    public String getTaskId() {
        return taskId;
    }

    public void setTaskId(String taskId) {
        this.taskId = taskId;
    }

    public String getActivityId() {
        return activityId;
    }

    public void setActivityId(String activityId) {
        this.activityId = activityId;
    }

    public boolean isAccepted() {
        return accepted;
    }

    public void setAccepted(boolean accepted) {
        this.accepted = accepted;
    }

    public PfUserVo getUserVo() {
        return userVo;
    }

    public void setUserVo(PfUserVo userVo) {
        this.userVo = userVo;
    }

    public HashMap getExtensionMap() {
        return extensionMap;
    }

    public void setExtensionMap(HashMap extensionMap) {
        this.extensionMap = extensionMap;
    }
}

==> egov-common-1.1.12.1-sources.jar: com/gtis/plat/vo/PfTaskVo.java <==
package com.gtis.plat.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.HashMap;

public class PfTaskVo implements Serializable {

    private String taskId;

    private String activityId;

    private boolean accepted;

    private PfUserVo userVo;

    private String remark;

    private boolean agree;

    private String performerId;

    private boolean backState;

    private String taskBefore = "";
    private Date beginTime;
    private Date finishTime;
    private boolean repeat;
    private Date overTime;    //任务截止时间

    //新增字段2019-05-15
    private boolean taskStatus;//任务状态(不动产)

    private Date acceptedTime;//任务读取时间(政务)

    private String optUser;//操作人员(不动产)

    private String optUserId;//操作人员id(不动产)

    private boolean isRestart;//是否重办

    /**
     * 扩展参数
     * 方便以后平台扩展，不用每次都要修改实体类
     */
    HashMap extensionMap;

    public Date getOverTime() {
        return overTime;
    }

    public void setOverTime(Date overTime) {
        this.overTime = overTime;
    }

    public boolean isRepeat() {
        return repeat;
    }

    public void setRepeat(boolean repeat) {
        this.repeat = repeat;
    }

    public Date getFinishTime() {
        return finishTime;
    }

    public void setFinishTime(Date finishTime) {
        this.finishTime = finishTime;
    }

    public Date getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(Date beginTime) {
        this.beginTime = beginTime;
    }

    public boolean isBackState() {
        return backState;
    }

    public void setBackState(boolean backState) {
        this.backState = backState;
    }

    public String getTaskBefore() {
        return taskBefore;
    }

    public void setTaskBefore(String taskBefore) {
        this.taskBefore = taskBefore;
    }

    public String getPerformerId() {
        return performerId;
    }

    public void setPerformerId(String performerId) {
        this.performerId = performerId;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public boolean isAgree() {
        return agree;
    }

    public void setAgree(boolean agree) {
        this.agree = agree;
    }

    public String getTaskId() {
        return taskId;
    }

    public void setTaskId(String taskId) {
        this.taskId = taskId;
    }

    public String getActivityId() {
        return activityId;
    }

    public void setActivityId(String activityId) {
        this.activityId = activityId;
    }

    public boolean isAccepted() {
        return accepted;
    }

    public void setAccepted(boolean accepted) {
        this.accepted = accepted;
    }

    public PfUserVo getUserVo() {
        return userVo;
    }

    public void setUserVo(PfUserVo userVo) {
        this.userVo = userVo;
    }

    public HashMap getExtensionMap() {
        return extensionMap;
    }

    public void setExtensionMap(HashMap extensionMap) {
        this.extensionMap = extensionMap;
    }

    public boolean isTaskStatus() {
        return taskStatus;
    }

    public void setTaskStatus(boolean taskStatus) {
        this.taskStatus = taskStatus;
    }

    public Date getAcceptedTime() {
        return acceptedTime;
    }

    public void setAcceptedTime(Date acceptedTime) {
        this.acceptedTime = acceptedTime;
    }

    public String getOptUser() {
        return optUser;
    }

    public void setOptUser(String optUser) {
        this.optUser = optUser;
    }

    public String getOptUserId() {
        return optUserId;
    }

    public void setOptUserId(String optUserId) {
        this.optUserId = optUserId;
    }

    public boolean isRestart() {
        return isRestart;
    }

    public void setRestart(boolean restart) {
        isRestart = restart;
    }
}
